@@ -95,7 +95,7 @@ const wxChar* about_txt = wxT("xCHM v. " VERSION
                               "Glasses logo by Anca Macinic.");
 
 #include <logo.xpm>
-#include <32x32/apps/xchm.xpm>
+#include <xchm.xpm>
 
 } // namespace
 
